summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kaccountsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kaccountsview.h')
-rw-r--r--kmymoney2/views/kaccountsview.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmymoney2/views/kaccountsview.h b/kmymoney2/views/kaccountsview.h
index 33a787c..a8498fb 100644
--- a/kmymoney2/views/kaccountsview.h
+++ b/kmymoney2/views/kaccountsview.h
@@ -49,12 +49,12 @@ public:
/**
* Constructor to be used to construct an account icon object.
*
* @param tqparent pointer to the KIconView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KIconView entry is constructed
*/
- KMyMoneyAccountIconItem(TQIconView *tqparent, const MyMoneyAccount& account);
+ KMyMoneyAccountIconItem(TQIconView *parent, const MyMoneyAccount& account);
~KMyMoneyAccountIconItem();
/**
@@ -91,7 +91,7 @@ class KAccountsView : public KAccountsViewDecl
private:
public:
- KAccountsView(TQWidget *tqparent=0, const char *name=0);
+ KAccountsView(TQWidget *parent=0, const char *name=0);
virtual ~KAccountsView();
public slots:
@@ -137,7 +137,7 @@ protected:
void loadListView(void);
void loadIconView(void);
- bool loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const TQStringList& accountList);
+ bool loadSubAccounts(KMyMoneyAccountTreeItem* parent, const TQStringList& accountList);
/**
* This method returns a pointer to the currently selected
@@ -182,12 +182,12 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
* account @p acc to be a subordinate account of @p tqparent.
*
* @param acc const reference to account to be reparented
* @param tqparent const reference to new tqparent account
*/
- void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& tqparent);
+ void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& parent);
private:
MyMoneyAccount m_reconciliationAccount;
@@ -49,12 +49,12 @@ public:
* Constructor to be used to construct an account icon object.
*
- * @param tqparent pointer to the KIconView object this entry should be
+ * @param parent pointer to the KIconView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -182,12 +182,12 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
- * account @p acc to be a subordinate account of @p tqparent.
+ * account @p acc to be a subordinate account of @p parent.
*
* @param acc const reference to account to be reparented
@@ -182,12 +182,12 @@ signals:
*
* @param acc const reference to account to be reparented
- * @param tqparent const reference to new tqparent account
+ * @param parent const reference to new parent account
*/